"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCodeMirror = useCodeMirror;

var _react = require("react");

var _basicSetup = require("@codemirror/basic-setup");

var _state = require("@codemirror/state");

var _commands = require("@codemirror/commands");

var _view = require("@codemirror/view");

var _themeOneDark = require("@codemirror/theme-one-dark");

var _light = require("./theme/light");

function useCodeMirror(props) {
  var {
    value,
    selection,
    onChange,
    onUpdate,
    extensions = [],
    autoFocus,
    theme = 'light',
    height = '',
    minHeight = '',
    maxHeight = '',
    width = '',
    minWidth = '',
    maxWidth = ''
  } = props;
  var [container, setContainer] = (0, _react.useState)(props.container);
  var [view, setView] = (0, _react.useState)();
  var [state, setState] = (0, _react.useState)();

  var defaultThemeOption = _view.EditorView.theme({
    '&': {
      height,
      minHeight,
      maxHeight,
      width,
      minWidth,
      maxWidth
    }
  });

  var updateListener = _view.EditorView.updateListener.of(vu => {
    if (vu.docChanged && typeof onChange === 'function') {
      var doc = vu.state.doc;

      var _value = doc.toString();

      onChange(_value, vu);
    }
  });

  var getExtensions = [_basicSetup.basicSetup, _view.keymap.of([_commands.indentWithTab]), updateListener, defaultThemeOption];
  theme === 'light' ? getExtensions.push(_light.defaultLightThemeOption) : getExtensions.push(_themeOneDark.oneDarkTheme);

  if (onUpdate && typeof onUpdate === 'function') {
    getExtensions.push(_view.EditorView.updateListener.of(onUpdate));
  }

  getExtensions = getExtensions.concat(extensions);
  (0, _react.useEffect)(() => {
    if (container && !state) {
      var stateCurrent = _state.EditorState.create({
        doc: value,
        selection,
        extensions: getExtensions
      });

      setState(stateCurrent);

      if (!view) {
        var viewCurrent = new _view.EditorView({
          state: stateCurrent,
          parent: container
        });
        setView(viewCurrent);
      }
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [container, state]);
  (0, _react.useEffect)(() => {
    return () => {
      if (view) {
        view.destroy();
      }
    };
  }, [view]);
  (0, _react.useEffect)(() => {
    if (view) {
      var currentValue = view.state.doc.toString();
      view.dispatch({
        changes: {
          from: 0,
          to: currentValue.length,
          insert: value || ''
        }
      });
    }
  }, [value, view]);
  (0, _react.useEffect)(() => {
    if (view) {
      view.dispatch({
        effects: _state.StateEffect.reconfigure.of(getExtensions)
      });
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [theme, extensions, height, minHeight, maxHeight, width, minWidth, maxWidth]);
  (0, _react.useEffect)(() => {
    if (autoFocus && view) {
      view.focus();
    }
  }, [autoFocus, view]);
  return {
    state,
    setState,
    view,
    setView,
    container,
    setContainer
  };
}
//# sourceMappingURL=useCodeMirror.js.map